/***************************************************************************
                          k2guitune.cpp  -  description
                             -------------------
    begin                : Sun Aug  5 15:37:33 CEST 2001
    copyright            : (C) 2001 by Florian Berger
    email                : harpin_floh@yahoo.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

// include files for QT
#include <qdir.h>
#include <qprinter.h>
#include <qpainter.h>

// include files for KDE
#include <kiconloader.h>
#include <kmessagebox.h>
#include <kfiledialog.h>
#include <kmenubar.h>
#include <klocale.h>
#include <kconfig.h>
#include <kstdaction.h>

// application specific includes
#include "k2guitune.h"
//#include "k2guituneview.h"
//#include "k2guitunedoc.h"
#include "aboutbox.h"
#include "guitune.h"

#define ID_STATUS_MSG 1

K2GuituneApp::K2GuituneApp(QWidget* , const char* name):KMainWindow(0, name)
{
  config=kapp->config();

  ///////////////////////////////////////////////////////////////////
  // call inits to invoke all other construction parts
  initStatusBar();
  initActions();
  initView();
	
  readOptions();

}

K2GuituneApp::~K2GuituneApp()
{

}

void K2GuituneApp::initActions()
{
  fileQuit = KStdAction::quit(this, SLOT(slotFileQuit()), actionCollection());
  viewToolBar = KStdAction::showToolbar(this, SLOT(slotViewToolBar()), actionCollection());
  viewStatusBar = KStdAction::showStatusbar(this, SLOT(slotViewStatusBar()), actionCollection());

  fileQuit->setStatusText(i18n("Quits the application"));
  viewToolBar->setStatusText(i18n("Enables/disables the toolbar"));
  viewStatusBar->setStatusText(i18n("Enables/disables the statusbar"));

  // use the absolute path to your k2guituneui.rc file for testing purpose in createGUI();
  createGUI();

//    filemenu = new QPopupMenu( this,"file_menu" );
//    filemenu->setFont( QFont("OldEnglish") );
//    filemenu->insertItem( "E&xit", qApp, SLOT( quit() ), ALT+Key_X );

    tuningmenu = new QPopupMenu( this,"view_menu" );
    tuningmenu->setFont( QFont("OldEnglish") );
    idm_tuning_norm =
    tuningmenu->insertItem( "&Normal",   this, SLOT( m_tuning_norm() ) );
    idm_tuning_wien =
    tuningmenu->insertItem( "&Wien",     this, SLOT( m_tuning_wien() ) );
    idm_tuning_phys =
    tuningmenu->insertItem( "&Physical", this, SLOT( m_tuning_phys() ) );
    tuningmenu->insertSeparator();
    idm_tuning_equi =
    tuningmenu->insertItem( "&Equidistant", this, SLOT( m_tuning_equi() ) );
    idm_tuning_nat =
    tuningmenu->insertItem( "N&atural",     this, SLOT( m_tuning_nat() ) );
    tuningmenu->setCheckable( TRUE );
    tuningmenu->setItemChecked( idm_tuning_norm, true );
    tuningmenu->setItemChecked( idm_tuning_equi, true );

    scalemenu = new QPopupMenu( this,"view_menu" );
    scalemenu->setFont( QFont("OldEnglish") );
    idm_scale_US =
    scalemenu->insertItem( "&US",           this, SLOT( m_scale_US()  ) );
    idm_scale_USa =
    scalemenu->insertItem( "U&S-Alternate", this, SLOT( m_scale_USa() ) );
    idm_scale_GE =
    scalemenu->insertItem( "&German",       this, SLOT( m_scale_GE()  ) );
    idm_scale_GEa =
    scalemenu->insertItem( "G&erman-Alt.",  this, SLOT( m_scale_GEa() ) );
    scalemenu->setCheckable( TRUE );
    scalemenu->setItemChecked( idm_scale_US, true );

    optmenu = new QPopupMenu( this,"options_menu" );
    optmenu->setFont( QFont("OldEnglish") );
    optmenu->insertItem( "&Tuning", tuningmenu );
    optmenu->insertItem( "&Note Scale", scalemenu );

//    helpmenu = new QPopupMenu( this,"help_menu" );
//    helpmenu->setFont( QFont("OldEnglish") );
//    helpmenu->insertItem( "&About",  this, SLOT( m_about() ) );

//    menuBar()->setFont( QFont("OldEnglish") );
//    menuBar()->insertItem( "&File", filemenu );
    menuBar()->insertItem( "&Options", optmenu, -1, 1 );
//    menuBar()->insertItem( "&Help", helpmenu );

}


void K2GuituneApp::initStatusBar()
{
  ///////////////////////////////////////////////////////////////////
  // STATUSBAR
  // TODO: add your own items you need for displaying current application status.
  statusBar()->insertItem(i18n("Ready."), ID_STATUS_MSG);
}

void K2GuituneApp::initView()
{ 
  ////////////////////////////////////////////////////////////////////
  // create the main widget here that is managed by KTMainWindow's view-region and
  // connect the widget to your document to display document contents.

  view = new MainWidget(this,"MainWidget",0,(char **)0);
//  view = new K2GuituneView(this);
  setCentralWidget(view);	
//  setCaption(doc->URL().fileName(),false);

}

void K2GuituneApp::saveOptions()
{	
  config->setGroup("General Options");
  config->writeEntry("Geometry", size());
  config->writeEntry("Show Toolbar", viewToolBar->isChecked());
  config->writeEntry("Show Statusbar",viewStatusBar->isChecked());
  config->writeEntry("ToolBarPos", (int) toolBar("mainToolBar")->barPos());
//  fileOpenRecent->saveEntries(config,"Recent Files");
}


void K2GuituneApp::readOptions()
{
	
  config->setGroup("General Options");

  // bar status settings
  bool bViewToolbar = config->readBoolEntry("Show Toolbar", true);
  viewToolBar->setChecked(bViewToolbar);
  slotViewToolBar();

  bool bViewStatusbar = config->readBoolEntry("Show Statusbar", true);
  viewStatusBar->setChecked(bViewStatusbar);
  slotViewStatusBar();


  // bar position settings
  KToolBar::BarPosition toolBarPos;
  toolBarPos=(KToolBar::BarPosition) config->readNumEntry("ToolBarPos", KToolBar::Top);
  toolBar("mainToolBar")->setBarPos(toolBarPos);
	
  QSize size=config->readSizeEntry("Geometry");
  if(!size.isEmpty())
  {
    resize(size);
  }
}

void K2GuituneApp::saveProperties(KConfig *_cfg)
{
}


void K2GuituneApp::readProperties(KConfig* _cfg)
{
}		

bool K2GuituneApp::queryClose()
{
}

bool K2GuituneApp::queryExit()
{
  saveOptions();
  return true;
}

/////////////////////////////////////////////////////////////////////
// SLOT IMPLEMENTATION
/////////////////////////////////////////////////////////////////////

void K2GuituneApp::slotFileQuit()
{
  slotStatusMsg(i18n("Exiting..."));
  saveOptions();
  // close the first window, the list makes the next one the first again.
  // This ensures that queryClose() is called on each window to ask for closing
  KMainWindow* w;
  if(memberList)
  {
    for(w=memberList->first(); w!=0; w=memberList->first())
    {
      // only close the window if the closeEvent is accepted. If the user presses Cancel on the saveModified() dialog,
      // the window and the application stay open.
      if(!w->close())
	break;
    }
  }	
  slotStatusMsg(i18n("Ready."));
}

void K2GuituneApp::slotViewToolBar()
{
  slotStatusMsg(i18n("Toggling toolbar..."));
  ///////////////////////////////////////////////////////////////////
  // turn Toolbar on or off
  if(!viewToolBar->isChecked())
  {
    toolBar("mainToolBar")->hide();
  }
  else
  {
    toolBar("mainToolBar")->show();
  }		

  slotStatusMsg(i18n("Ready."));
}

void K2GuituneApp::slotViewStatusBar()
{
  slotStatusMsg(i18n("Toggle the statusbar..."));
  ///////////////////////////////////////////////////////////////////
  //turn Statusbar on or off
  if(!viewStatusBar->isChecked())
  {
    statusBar()->hide();
  }
  else
  {
    statusBar()->show();
  }

  slotStatusMsg(i18n("Ready."));
}


void K2GuituneApp::slotStatusMsg(const QString &text)
{
  ///////////////////////////////////////////////////////////////////
  // change status message permanently
  statusBar()->clear();
  statusBar()->changeItem(text, ID_STATUS_MSG);
}


void K2GuituneApp::m_tuning_norm()
{
    view->setTuningNorm();
    tuningmenu->setItemChecked( idm_tuning_norm, true );
    tuningmenu->setItemChecked( idm_tuning_wien, false );
    tuningmenu->setItemChecked( idm_tuning_phys, false );
}
void K2GuituneApp::m_tuning_wien()
{
    view->setTuningWien();
    tuningmenu->setItemChecked( idm_tuning_norm, false );
    tuningmenu->setItemChecked( idm_tuning_wien, true );
    tuningmenu->setItemChecked( idm_tuning_phys, false );
}
void K2GuituneApp::m_tuning_phys()
{
    view->setTuningPhys();
    tuningmenu->setItemChecked( idm_tuning_norm, false );
    tuningmenu->setItemChecked( idm_tuning_wien, false );
    tuningmenu->setItemChecked( idm_tuning_phys, true );
}

void K2GuituneApp::m_tuning_equi()
{
    view->setTuningEqui();
    tuningmenu->setItemChecked( idm_tuning_equi, true  );
    tuningmenu->setItemChecked( idm_tuning_nat,  false );
}
void K2GuituneApp::m_tuning_nat()
{
    view->setTuningNat();
    tuningmenu->setItemChecked( idm_tuning_equi, false );
    tuningmenu->setItemChecked( idm_tuning_nat,  true  );
}

void K2GuituneApp::m_scale_US()
{
    view->setScaleUS();
    scalemenu->setItemChecked( idm_scale_US,  true  );
    scalemenu->setItemChecked( idm_scale_USa, false );
    scalemenu->setItemChecked( idm_scale_GE,  false  );
    scalemenu->setItemChecked( idm_scale_GEa, false );
}
void K2GuituneApp::m_scale_USa()
{
    view->setScaleUSAlt();
    scalemenu->setItemChecked( idm_scale_US,  false );
    scalemenu->setItemChecked( idm_scale_USa, true  );
    scalemenu->setItemChecked( idm_scale_GE,  false );
    scalemenu->setItemChecked( idm_scale_GEa, false );
}
void K2GuituneApp::m_scale_GE()
{
    view->setScaleGE();
    scalemenu->setItemChecked( idm_scale_US,  false );
    scalemenu->setItemChecked( idm_scale_USa, false );
    scalemenu->setItemChecked( idm_scale_GE,  true  );
    scalemenu->setItemChecked( idm_scale_GEa, false );
}
void K2GuituneApp::m_scale_GEa()
{
    view->setScaleGEAlt();
    scalemenu->setItemChecked( idm_scale_US,  false );
    scalemenu->setItemChecked( idm_scale_USa, false );
    scalemenu->setItemChecked( idm_scale_GE,  false );
    scalemenu->setItemChecked( idm_scale_GEa, true  );
}
void K2GuituneApp::m_about()
{
    AboutBox * ab = new AboutBox( 0, "AboutBox" );
    ab->show();
    ab->resize(200,320);
    ab->setMinimumSize(300,300);
}
